@@ -1,6 +1,6 @@
 use v6;
 
-unit module TAP:ver<0.3.3>;
+unit module TAP:ver<0.3.4>;
 
 role Entry {
     has Str:D $.raw is required handles <Str>;
@@ -890,7 +890,7 @@ class Harness {
     }
     class SourceHandler::Raku does SourceHandler::Proc {
         has Str:D $.path = $*EXECUTABLE.absolute;
-        has Str @.incdirs;
+        has Str(IO) @.incdirs;
         method make-source(Str:D $name, Any:D :$err, IO::Path:D :$cwd, :@include-dirs = (), *%) {
             my @dirs = map { normalize-path($_, $cwd) }, |@include-dirs, |@!incdirs;
             my @args = |@dirs.map("-I" ~ *), $name;
